﻿using UnityEngine;
using System.Collections;

public class Player : MonoBehaviour
{
    public AudioClip deathSound;
    public AudioClip jumpSound;
    public AudioClip victorySound;
    public float maxSpeed = 7f;
    public float speed = 75f;
    public float jumpPower = 300f;

    public bool victory;
    public bool death;
    public bool grounded;
    public bool canDoubleJump;

    private Rigidbody2D rb2D;
    private Animator anim;
    private AudioSource source;
    private bool sound;


    void Start()
    {
        rb2D = gameObject.GetComponent<Rigidbody2D>();
        anim = gameObject.GetComponent<Animator>();
        death = false;
        victory = false;
        sound = true;
        source = GetComponent<AudioSource>();
    }


    void Update()
    {
        anim.SetBool("Grounded", grounded);
        anim.SetFloat("Speed", Mathf.Abs(rb2D.velocity.x));

        if (Input.GetAxis("Horizontal") < -0.1f)
        {
            transform.localScale = new Vector3(-1, 1, 1);
        }
        if (Input.GetAxis("Horizontal") > 0.1f)
        {
            transform.localScale = new Vector3(1, 1, 1);
        }
        if (Input.GetButtonDown("Jump"))
        {
            if (grounded)
            {
                source.PlayOneShot(jumpSound, 0.7f);
                rb2D.AddForce(Vector2.up * jumpPower);
                canDoubleJump = true;
            }
            else
            {
                if (canDoubleJump)
                {
                    source.PlayOneShot(jumpSound, 0.7f);
                    canDoubleJump = false;
                    rb2D.velocity = new Vector2(rb2D.velocity.x, 0);
                    rb2D.AddForce(Vector2.up * jumpPower);
                }
            }
        }

        if(victory && sound)
        {
            source.PlayOneShot(victorySound, 0.7f);
            sound = false;
        }
        if (death && sound)
        {
            source.PlayOneShot(deathSound, 0.7f);
            sound = false;
        }


    }

    void FixedUpdate()
    {

        Vector3 easeVelocity = rb2D.velocity;
        easeVelocity.y = rb2D.velocity.y;
        easeVelocity.z = 0.2f;
        easeVelocity.x *= 0.7f;
        
        //Get input to move player
        float h = Input.GetAxis("Horizontal");

        //Fake friction
        if (grounded)
        {
            rb2D.velocity = easeVelocity;
        }

        //Moving player
        rb2D.AddForce((Vector2.right * speed) * h);


        //limiting players speed
        if (rb2D.velocity.x > maxSpeed)
        {
            rb2D.velocity = new Vector2(maxSpeed, rb2D.velocity.y);
        }
        if (rb2D.velocity.x < -maxSpeed)
        {
            rb2D.velocity = new Vector2(-maxSpeed, rb2D.velocity.y);
        }
    }
}
